@@ -545,7 +545,8 @@ class ActivityPub:
         form_data = aiohttp.FormData()
         form_data.add_field(name="status", value=status)
         form_data.add_field(name="visibility", value=visibility)
-        form_data.add_field(name="sensitive", value=sensitive)
+        if sensitive:
+            form_data.add_field(name="sensitive", value="true")
         if media_ids:
             form_data.add_field(name="media_ids[]", value=media_ids)
         if spoiler_text:
